@@ -1,14 +1,9 @@
-from logging import getLogger
-
 import ldap
 
 from ooldap import GLOBAL_GROUP
 from ooldap.foundation import LDAPObject
 
 
-log = getLogger('ooldap.objects')
-
-
 class Group(LDAPObject):
     def create(self, name, scope=GLOBAL_GROUP):
         attr = {}
@@ -21,11 +16,7 @@ class Group(LDAPObject):
         add_group = ldap.modlist.addModlist(attr)
 
         self.connection.bind()
-        try:
-            log.debug('creating group %s' % self.dn)
-            self.connection.stream.add_s(self.dn, add_group)
-        except ldap.ALREADY_EXISTS:
-            pass
+        self.connection.stream.add_s(self.dn, add_group)
         self.connection.unbind()
 
     @property
@@ -33,19 +24,14 @@ class Group(LDAPObject):
         return self.get_attribute('member')
 
     def add_member(self, new_member):
+        assert isinstance(new_member, LDAPObject)
         self.connection.bind()
-        try:
-            self.connection.stream.modify_s(self.dn,
-                       [(ldap.MOD_ADD, 'member', str(new_member.dn))])
-        except ldap.ALREADY_EXISTS:
-            pass
+        self.connection.stream.modify_s(self.dn,
+                    [(ldap.MOD_ADD, 'member', str(new_member.dn))])
         self.connection.unbind()
 
     def remove_member(self, member):
         self.connection.bind()
-        try:
-            self.connection.stream.modify_s(self.dn,
-                       [(ldap.MOD_DELETE, 'member', str(member.dn))])
-        except ldap.NO_SUCH_OBJECT:
-            pass
+        self.connection.stream.modify_s(self.dn,
+                    [(ldap.MOD_DELETE, 'member', str(member.dn))])
         self.connection.unbind()
